@@ -70,7 +70,7 @@ use Exporter::Tidy
   };
 
 our @ISA     = 'DBI';
-our $VERSION = '0.0.33_1';
+our $VERSION = '0.0.34';
 
 sub _ejoin {
     my $joiner = shift;
@@ -457,6 +457,19 @@ sub log_debug {
     $log->debug($out);
 }
 
+sub log_warn {
+    my $self = shift;
+    my $sql  = (shift) . "\n";
+
+    my $sth = $self->prepare( $sql . ';' );
+    $sth->execute(@_);
+
+    my $out = join( ', ', @{ $sth->{NAME} } ) . "\n";
+    $out .= '  ' . ( '-' x length $out ) . "\n";
+    $out .= '  ' . DBI::neat_list($_) . "\n" for @{ $sth->fetchall_arrayref };
+    warn $out;
+}
+
 sub dump {
     my $self = shift;
     my $sth  = $self->prepare(shift);
